library bizdoc;

import 'package:bizdoc/authenticate/base.dart';
import 'package:bizdoc/generics/analysis.dart';
import 'package:bizdoc/services/network.dart';
import 'package:bizdoc/services/session.dart';
import 'package:flutter/material.dart';

import 'configuration.dart';

class AppState extends ChangeNotifier {
  final String? serverAddress;
  final Map<String, Widget Function(BuildContext context)> _resolvers = {
    'bizdoc-cube-analysis': (ctx) => const CubeAnalysisWidget()
  };
  final GoogleMapsSettings? googleMaps;
  final AuthenticationBase authentication;
  final FirebaseSettings? firebaseSettings;
  AppState(Map<String, Widget Function(BuildContext context)>? resolve,
      this.authentication,
      {this.serverAddress, this.googleMaps, this.firebaseSettings}) {
    if (resolve != null) _resolvers.addAll(resolve);
  }
  Widget? resolve(String name, BuildContext context) {
    return _resolvers.containsKey(name) ? _resolvers[name]!(context) : null;
  }

  recycle() {
    network.initialize(this);
    session.refresh();
    notifyListeners();
  }
}
