library bizdoc;

extension FirstWhereOrNullExtension<E> on Iterable<E> {
  E? firstWhereOrNull(bool Function(E) test) {
    for (E element in this) {
      if (test(element)) return element;
    }
    return null;
  }
}

extension DistinctExtension<E> on Iterable<E> {
  Iterable<V> distinctWhere<V>(V Function(E) test) {
    final values = <V>{};
    for (E element in this) {
      var value = test(element);
      if (!values.contains(value)) values.add(value);
    }
    return values;
  }

  num sum<V>(num Function(E) test) {
    num sum = 0;
    for (E element in this) {
      var value = test(element);
      sum += value;
    }
    return sum;
  }

  Iterable<E> distinct() {
    final elements = <E>{};
    for (E element in this) {
      if (!elements.contains(element)) elements.add(element);
    }
    return elements;
  }
}

extension StringExtension on String {
  String format(List<String> params) => interpolate(this, params);
}

String interpolate(String string, List<String> params) {
  String result = string;
  for (int i = 1; i < params.length + 1; i++) {
    result = result.replaceAll('%$i\$', params[i - 1]);
  }

  return result;
}
