library bizdoc;

import 'dart:async';

import 'package:flutter/material.dart';

/// State shared between [ComposePage] and custom form components, such as [MyForm]
class BizDocFormState extends ChangeNotifier {
  final dynamic _model;
  final ViewMode _viewMode;
  final _validController = StreamController<bool>.broadcast();
  final _dirtyController = StreamController<bool>.broadcast();
  final _stateController = StreamController.broadcast();

  Map<String, dynamic> get data => _model.data;

  dynamic get model => _model;
  ViewMode get mode => _viewMode;

  BizDocFormState(this._model, this._viewMode);
  Stream<bool> get valid => _validController.stream;
  Stream<bool> get dirty => _dirtyController.stream;
  Stream get state => _stateController.stream;

  setValid() => _validController.add(true);

  setInvalid() => _validController.add(false);

  setDirty() => _dirtyController.add(true);

  setPristine() {
    _dirtyController.add(false);
  }

  reset() {
    _stateController.add(true);
  }

  @override
  dispose() {
    _validController.close();
    _dirtyController.close();
    _stateController.close();
    super.dispose();
  }
}

enum ViewMode { compose, preview }
