// import 'package:awesome_notifications/awesome_notifications.dart';
import 'package:bizdoc/services/accounts.dart';
import 'package:flutter_local_notifications/flutter_local_notifications.dart';

import 'package:bizdoc/models/contracts.dart';
import 'package:bizdoc/models/notifications.dart';

class NotificationsService {
  static final NotificationsService _notificationService =
      NotificationsService._internal();

  final FlutterLocalNotificationsPlugin _flutterLocalNotificationsPlugin =
      FlutterLocalNotificationsPlugin();

  factory NotificationsService() {
    return _notificationService;
  }

  final IOSInitializationSettings initializationSettingsIOS =
      const IOSInitializationSettings(
    requestSoundPermission: false,
    requestBadgePermission: false,
    requestAlertPermission: false,
    onDidReceiveLocalNotification: onDidReceiveLocalNotification,
  );
  void initialize() async {
    _flutterLocalNotificationsPlugin.initialize(
        InitializationSettings(
          android: const AndroidInitializationSettings('ic_launcher'),
          iOS: initializationSettingsIOS,
        ),
        onSelectNotification: selectNotification);

    // AwesomeNotifications().initialize(
    //     // set the icon to null if you want to use the default app icon
    //     null,
    //     [
    //       NotificationChannel(
    //           channelKey: 'basic_channel',
    //           channelName: 'Basic notifications',
    //           channelDescription: 'Notification channel for basic tests',
    //           defaultColor: Color(0xFF9D50DD),
    //           ledColor: Colors.white)
    //     ]);
    // AwesomeNotifications().isNotificationAllowed().then((isAllowed) {
    //   if (!isAllowed) {
    //     // Insert here your friendly dialog box before call the request method
    //     // This is very important to not harm the user experience
    //     AwesomeNotifications().requestPermissionToSendNotifications();
    //   }
    // });
  }

  Future<void> notify(ContractBase? contract, String payload) async {
    const IOSNotificationDetails iOSPlatformChannelSpecifics =
        IOSNotificationDetails(
      presentAlert:
          true, // Present an alert when the notification is displayed and the application is in the foreground (only from iOS 10 onwards)
      // presentBadge: true,  // Present the badge number when the notification is displayed and the application is in the foreground (only from iOS 10 onwards)
      presentSound:
          true, // Play a sound when the notification is displayed and the application is in the foreground (only from iOS 10 onwards)
      // sound: String?,  // Specifics the file path to play (only from iOS 10 onwards)
      // badgeNumber: int?, // The application's icon badge number
      // attachments: List<IOSNotificationAttachment>?, (only from iOS 10 onwards)
      // subtitle: String?, //Secondary description  (only from iOS 10 onwards)
      // threadIdentifier: String? (only from iOS 10 onwards)
    );
    const AndroidNotificationDetails androidPlatformChannelSpecifics =
        AndroidNotificationDetails(
      'bizdoc',
      'BizDoc',
      'BizDoc',
      importance: Importance.max,
      priority: Priority.high,
    );
    const NotificationDetails platformChannelSpecifics = NotificationDetails(
        android: androidPlatformChannelSpecifics,
        iOS: iOSPlatformChannelSpecifics);

    if (contract is NewMail) {
      // final actions = appData.profile.actions
      //     .where((element) => contract.model.actions!.contains(element.name));
      try {
        await _flutterLocalNotificationsPlugin.show(
            contract.model.id,
            contract.model.subject,
            contract.model.summary,
            platformChannelSpecifics,
            payload: payload);
      } on Exception catch (e) {
        print(e);
      }
    } else if (contract is NewChat) {
      try {
        final info = await users.find(contract.model.userId);
        await _flutterLocalNotificationsPlugin.show(
            contract.model.time.millisecondsSinceEpoch,
            info.name,
            contract.model.text,
            platformChannelSpecifics,
            payload: payload);
      } catch (e) {}
    } else if (contract is NewNotify) {
      try {
        if (contract.model is CubeAnomaly) {}
        // await _flutterLocalNotificationsPlugin.show(
        //     contract.model.time.millisecondsSinceEpoch,
        //     info.name,
        //     contract.model.text,
        //     platformChannelSpecifics,
        //     payload: payload);
      } catch (e) {}
    }
  }

  /// device notification interaction [Hub]
  // _listen(BuildContext context) {
  // AwesomeNotifications().actionStream.listen((receivedNotification) {
  //   switch (receivedNotification.actionDate) {
  //     default:
  //       Navigator.of(context).pushNamed(ComposePage.routeName,
  //           arguments: ComposeModel.fromJson(
  //               jsonDecode(receivedNotification.createdDate!)));
  //   }
  // });
  // }

  NotificationsService._internal();

  static Future onDidReceiveLocalNotification(
      int id, String? title, String? body, String? payload) async {}

  Future selectNotification(String? payload) async {}
}

final notifications = NotificationsService();
