
import 'dart:async';

import 'package:flutter/foundation.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter_localizations/flutter_localizations.dart';
import 'package:intl/intl.dart' as intl;

import 'app_localizations_en.dart';
import 'app_localizations_es.dart';

/// Callers can lookup localized strings with an instance of AppLocalizations returned
/// by `AppLocalizations.of(context)`.
///
/// Applications need to include `AppLocalizations.delegate()` in their app's
/// localizationDelegates list, and the locales they support in the app's
/// supportedLocales list. For example:
///
/// ```
/// import 'gen_l10n/app_localizations.dart';
///
/// return MaterialApp(
///   localizationsDelegates: AppLocalizations.localizationsDelegates,
///   supportedLocales: AppLocalizations.supportedLocales,
///   home: MyApplicationHome(),
/// );
/// ```
///
/// ## Update pubspec.yaml
///
/// Please make sure to update your pubspec.yaml to include the following
/// packages:
///
/// ```
/// dependencies:
///   # Internationalization support.
///   flutter_localizations:
///     sdk: flutter
///   intl: any # Use the pinned version from flutter_localizations
///
///   # rest of dependencies
/// ```
///
/// ## iOS Applications
///
/// iOS applications define key application metadata, including supported
/// locales, in an Info.plist file that is built into the application bundle.
/// To configure the locales supported by your app, you’ll need to edit this
/// file.
///
/// First, open your project’s ios/Runner.xcworkspace Xcode workspace file.
/// Then, in the Project Navigator, open the Info.plist file under the Runner
/// project’s Runner folder.
///
/// Next, select the Information Property List item, select Add Item from the
/// Editor menu, then select Localizations from the pop-up menu.
///
/// Select and expand the newly-created Localizations item then, for each
/// locale your application supports, add a new item and select the locale
/// you wish to add from the pop-up menu in the Value field. This list should
/// be consistent with the languages listed in the AppLocalizations.supportedLocales
/// property.
abstract class AppLocalizations {
  AppLocalizations(String locale) : localeName = intl.Intl.canonicalizedLocale(locale.toString());

  final String localeName;

  static AppLocalizations? of(BuildContext context) {
    return Localizations.of<AppLocalizations>(context, AppLocalizations);
  }

  static const LocalizationsDelegate<AppLocalizations> delegate = _AppLocalizationsDelegate();

  /// A list of this localizations delegate along with the default localizations
  /// delegates.
  ///
  /// Returns a list of localizations delegates containing this delegate along with
  /// GlobalMaterialLocalizations.delegate, GlobalCupertinoLocalizations.delegate,
  /// and GlobalWidgetsLocalizations.delegate.
  ///
  /// Additional delegates can be added by appending to this list in
  /// MaterialApp. This list does not have to be used at all if a custom list
  /// of delegates is preferred or required.
  static const List<LocalizationsDelegate<dynamic>> localizationsDelegates = <LocalizationsDelegate<dynamic>>[
    delegate,
    GlobalMaterialLocalizations.delegate,
    GlobalCupertinoLocalizations.delegate,
    GlobalWidgetsLocalizations.delegate,
  ];

  /// A list of this localizations delegate's supported locales.
  static const List<Locale> supportedLocales = <Locale>[
    Locale('en'),
    Locale('es')
  ];

  /// No description provided for @appTitle.
  ///
  /// In en, this message translates to:
  /// **'Hello World!'**
  String get appTitle;

  /// No description provided for @loadMore.
  ///
  /// In en, this message translates to:
  /// **'Release to load more'**
  String get loadMore;

  /// No description provided for @err.
  ///
  /// In en, this message translates to:
  /// **'Oops! Something went wrong'**
  String get err;

  /// No description provided for @cancel.
  ///
  /// In en, this message translates to:
  /// **'Cancel'**
  String get cancel;

  /// No description provided for @oK.
  ///
  /// In en, this message translates to:
  /// **'OK'**
  String get oK;

  /// No description provided for @none.
  ///
  /// In en, this message translates to:
  /// **'- None'**
  String get none;

  /// No description provided for @dashboard.
  ///
  /// In en, this message translates to:
  /// **'Dashboard'**
  String get dashboard;

  /// No description provided for @password.
  ///
  /// In en, this message translates to:
  /// **'Password'**
  String get password;

  /// No description provided for @discard.
  ///
  /// In en, this message translates to:
  /// **'Discard'**
  String get discard;

  /// No description provided for @discardAsk.
  ///
  /// In en, this message translates to:
  /// **'Are you sure?'**
  String get discardAsk;

  /// No description provided for @conflictErr.
  ///
  /// In en, this message translates to:
  /// **'Edited by someone'**
  String get conflictErr;

  /// No description provided for @modifiedBy.
  ///
  /// In en, this message translates to:
  /// **'modified by %1\$'**
  String get modifiedBy;

  /// No description provided for @required.
  ///
  /// In en, this message translates to:
  /// **'Required'**
  String get required;

  /// No description provided for @username.
  ///
  /// In en, this message translates to:
  /// **'Username'**
  String get username;

  /// No description provided for @favorites.
  ///
  /// In en, this message translates to:
  /// **'Favorites'**
  String get favorites;

  /// No description provided for @submitted.
  ///
  /// In en, this message translates to:
  /// **'%1\$ submitted'**
  String get submitted;

  /// No description provided for @saved.
  ///
  /// In en, this message translates to:
  /// **'Changes saved'**
  String get saved;

  /// No description provided for @serverAddress.
  ///
  /// In en, this message translates to:
  /// **'Server address'**
  String get serverAddress;

  /// No description provided for @serverAddressErr.
  ///
  /// In en, this message translates to:
  /// **'Unreachable address'**
  String get serverAddressErr;

  /// No description provided for @typing.
  ///
  /// In en, this message translates to:
  /// **'Typing'**
  String get typing;

  /// No description provided for @typeHere.
  ///
  /// In en, this message translates to:
  /// **'Type here'**
  String get typeHere;

  /// No description provided for @you.
  ///
  /// In en, this message translates to:
  /// **'You'**
  String get you;

  /// No description provided for @itemsAction.
  ///
  /// In en, this message translates to:
  /// **'%1\$ items %2\$'**
  String get itemsAction;

  /// No description provided for @itemAction.
  ///
  /// In en, this message translates to:
  /// **'#%1\$ %2\$'**
  String get itemAction;

  /// No description provided for @amount.
  ///
  /// In en, this message translates to:
  /// **'Amount'**
  String get amount;

  /// No description provided for @address.
  ///
  /// In en, this message translates to:
  /// **'Address'**
  String get address;

  /// No description provided for @business.
  ///
  /// In en, this message translates to:
  /// **'Business'**
  String get business;

  /// No description provided for @date.
  ///
  /// In en, this message translates to:
  /// **'Date'**
  String get date;

  /// No description provided for @expenseType.
  ///
  /// In en, this message translates to:
  /// **'Expense type'**
  String get expenseType;

  /// No description provided for @prItemQtyErr.
  ///
  /// In en, this message translates to:
  /// **'Item qty'**
  String get prItemQtyErr;

  /// No description provided for @ytd.
  ///
  /// In en, this message translates to:
  /// **'YTD'**
  String get ytd;

  /// No description provided for @clear.
  ///
  /// In en, this message translates to:
  /// **'Clear'**
  String get clear;

  /// No description provided for @subject.
  ///
  /// In en, this message translates to:
  /// **'Subject'**
  String get subject;

  /// No description provided for @justification.
  ///
  /// In en, this message translates to:
  /// **'Justification'**
  String get justification;

  /// No description provided for @requiredErr.
  ///
  /// In en, this message translates to:
  /// **'Required'**
  String get requiredErr;

  /// No description provided for @poInfoErr.
  ///
  /// In en, this message translates to:
  /// **'Error'**
  String get poInfoErr;

  /// No description provided for @firstTime.
  ///
  /// In en, this message translates to:
  /// **'First Time'**
  String get firstTime;

  /// No description provided for @repeated.
  ///
  /// In en, this message translates to:
  /// **'Repeated'**
  String get repeated;

  /// No description provided for @partial.
  ///
  /// In en, this message translates to:
  /// **'Partial'**
  String get partial;

  /// No description provided for @full.
  ///
  /// In en, this message translates to:
  /// **'Full'**
  String get full;

  /// No description provided for @signed.
  ///
  /// In en, this message translates to:
  /// **'Signed'**
  String get signed;

  /// No description provided for @planned.
  ///
  /// In en, this message translates to:
  /// **'Planned'**
  String get planned;

  /// No description provided for @approved.
  ///
  /// In en, this message translates to:
  /// **'Approved'**
  String get approved;

  /// No description provided for @handled.
  ///
  /// In en, this message translates to:
  /// **'Handled'**
  String get handled;

  /// No description provided for @ocs.
  ///
  /// In en, this message translates to:
  /// **'OCS'**
  String get ocs;

  /// No description provided for @recentProjects.
  ///
  /// In en, this message translates to:
  /// **'Recent projects'**
  String get recentProjects;

  /// No description provided for @recentBudgets.
  ///
  /// In en, this message translates to:
  /// **'Recent budgets'**
  String get recentBudgets;

  /// No description provided for @recentOcs.
  ///
  /// In en, this message translates to:
  /// **'Recent OCS'**
  String get recentOcs;

  /// No description provided for @buyer.
  ///
  /// In en, this message translates to:
  /// **'Buyer'**
  String get buyer;

  /// No description provided for @tryAgain.
  ///
  /// In en, this message translates to:
  /// **'Try Again'**
  String get tryAgain;

  /// No description provided for @poDetails.
  ///
  /// In en, this message translates to:
  /// **'PO Details'**
  String get poDetails;

  /// No description provided for @module.
  ///
  /// In en, this message translates to:
  /// **'Module'**
  String get module;

  /// No description provided for @category.
  ///
  /// In en, this message translates to:
  /// **'Category'**
  String get category;

  /// No description provided for @subCategory.
  ///
  /// In en, this message translates to:
  /// **'Sub Category'**
  String get subCategory;

  /// No description provided for @catalogNumber.
  ///
  /// In en, this message translates to:
  /// **'Catalog Nbr'**
  String get catalogNumber;

  /// No description provided for @budget.
  ///
  /// In en, this message translates to:
  /// **'Budget'**
  String get budget;

  /// No description provided for @cdr.
  ///
  /// In en, this message translates to:
  /// **'CDR'**
  String get cdr;

  /// No description provided for @um.
  ///
  /// In en, this message translates to:
  /// **'Um'**
  String get um;

  /// No description provided for @price.
  ///
  /// In en, this message translates to:
  /// **'Price'**
  String get price;

  /// No description provided for @qty.
  ///
  /// In en, this message translates to:
  /// **'Qty'**
  String get qty;

  /// No description provided for @approvedQty.
  ///
  /// In en, this message translates to:
  /// **'Approved/Qty'**
  String get approvedQty;

  /// No description provided for @invoiceQty.
  ///
  /// In en, this message translates to:
  /// **'Invoice Qty'**
  String get invoiceQty;

  /// No description provided for @receiptQty.
  ///
  /// In en, this message translates to:
  /// **'Receipt Qty'**
  String get receiptQty;

  /// No description provided for @orderQty.
  ///
  /// In en, this message translates to:
  /// **'Order Qty'**
  String get orderQty;

  /// No description provided for @openQty.
  ///
  /// In en, this message translates to:
  /// **'Open Qty'**
  String get openQty;

  /// No description provided for @orderDate.
  ///
  /// In en, this message translates to:
  /// **'Order Date'**
  String get orderDate;

  /// No description provided for @invoiceDate.
  ///
  /// In en, this message translates to:
  /// **'Invoice Date'**
  String get invoiceDate;

  /// No description provided for @receiptDate.
  ///
  /// In en, this message translates to:
  /// **'Receipt Date'**
  String get receiptDate;

  /// No description provided for @voucher.
  ///
  /// In en, this message translates to:
  /// **'Voucher'**
  String get voucher;

  /// No description provided for @supplier.
  ///
  /// In en, this message translates to:
  /// **'Supplier'**
  String get supplier;

  /// No description provided for @receiver.
  ///
  /// In en, this message translates to:
  /// **'Receiver'**
  String get receiver;

  /// No description provided for @text.
  ///
  /// In en, this message translates to:
  /// **'Text'**
  String get text;

  /// No description provided for @total.
  ///
  /// In en, this message translates to:
  /// **'Total'**
  String get total;

  /// No description provided for @po.
  ///
  /// In en, this message translates to:
  /// **'PO'**
  String get po;

  /// No description provided for @so.
  ///
  /// In en, this message translates to:
  /// **'SO'**
  String get so;

  /// No description provided for @kpi.
  ///
  /// In en, this message translates to:
  /// **'KPI'**
  String get kpi;

  /// No description provided for @no.
  ///
  /// In en, this message translates to:
  /// **'No'**
  String get no;

  /// No description provided for @yes.
  ///
  /// In en, this message translates to:
  /// **'Yes'**
  String get yes;

  /// No description provided for @isReleasePart.
  ///
  /// In en, this message translates to:
  /// **'Release part'**
  String get isReleasePart;

  /// No description provided for @purchaseState.
  ///
  /// In en, this message translates to:
  /// **'Purchase State'**
  String get purchaseState;

  /// No description provided for @systemSpec.
  ///
  /// In en, this message translates to:
  /// **'System spec.'**
  String get systemSpec;

  /// No description provided for @vendor.
  ///
  /// In en, this message translates to:
  /// **'Vendor'**
  String get vendor;

  /// No description provided for @company.
  ///
  /// In en, this message translates to:
  /// **'Company'**
  String get company;

  /// No description provided for @cdrApproved.
  ///
  /// In en, this message translates to:
  /// **'CDR Approved'**
  String get cdrApproved;

  /// No description provided for @requestType.
  ///
  /// In en, this message translates to:
  /// **'Request Type'**
  String get requestType;

  /// No description provided for @level.
  ///
  /// In en, this message translates to:
  /// **'Level'**
  String get level;

  /// No description provided for @manufacturer.
  ///
  /// In en, this message translates to:
  /// **'Manufacturer'**
  String get manufacturer;

  /// No description provided for @project.
  ///
  /// In en, this message translates to:
  /// **'Project'**
  String get project;

  /// No description provided for @materialScrap.
  ///
  /// In en, this message translates to:
  /// **'Material Scrap'**
  String get materialScrap;

  /// No description provided for @buyType.
  ///
  /// In en, this message translates to:
  /// **'Buy Type'**
  String get buyType;

  /// No description provided for @low.
  ///
  /// In en, this message translates to:
  /// **'Low'**
  String get low;

  /// No description provided for @medium.
  ///
  /// In en, this message translates to:
  /// **'Medium'**
  String get medium;

  /// No description provided for @high.
  ///
  /// In en, this message translates to:
  /// **'High'**
  String get high;

  /// No description provided for @arrivalPayment.
  ///
  /// In en, this message translates to:
  /// **'Arrival Payment'**
  String get arrivalPayment;

  /// No description provided for @manufacturerPart.
  ///
  /// In en, this message translates to:
  /// **'Manufacturer Part'**
  String get manufacturerPart;

  /// No description provided for @deleteAsk.
  ///
  /// In en, this message translates to:
  /// **'Are you sure?'**
  String get deleteAsk;

  /// No description provided for @ok.
  ///
  /// In en, this message translates to:
  /// **'Ok'**
  String get ok;

  /// No description provided for @isUrgent.
  ///
  /// In en, this message translates to:
  /// **'Urgent'**
  String get isUrgent;

  /// No description provided for @rate.
  ///
  /// In en, this message translates to:
  /// **'Rate %1\$'**
  String get rate;

  /// No description provided for @comments.
  ///
  /// In en, this message translates to:
  /// **'Comments'**
  String get comments;

  /// No description provided for @flights.
  ///
  /// In en, this message translates to:
  /// **'Flights'**
  String get flights;

  /// No description provided for @totalPerDiem.
  ///
  /// In en, this message translates to:
  /// **'Total Per Diem'**
  String get totalPerDiem;

  /// No description provided for @perDiem.
  ///
  /// In en, this message translates to:
  /// **'Per Diem'**
  String get perDiem;

  /// No description provided for @daily.
  ///
  /// In en, this message translates to:
  /// **'Daily'**
  String get daily;

  /// No description provided for @percent.
  ///
  /// In en, this message translates to:
  /// **'Percent'**
  String get percent;

  /// No description provided for @percentErr.
  ///
  /// In en, this message translates to:
  /// **'100%'**
  String get percentErr;

  /// No description provided for @purposes.
  ///
  /// In en, this message translates to:
  /// **'Purposes'**
  String get purposes;

  /// No description provided for @purpose.
  ///
  /// In en, this message translates to:
  /// **'Purpose'**
  String get purpose;

  /// No description provided for @privateDays.
  ///
  /// In en, this message translates to:
  /// **'Private days'**
  String get privateDays;

  /// No description provided for @stayPeriods.
  ///
  /// In en, this message translates to:
  /// **'Stay Periods'**
  String get stayPeriods;

  /// No description provided for @advancedPayments.
  ///
  /// In en, this message translates to:
  /// **'Advanced Payments'**
  String get advancedPayments;

  /// No description provided for @isCustomerPaid.
  ///
  /// In en, this message translates to:
  /// **'Customer paid'**
  String get isCustomerPaid;

  /// No description provided for @financials.
  ///
  /// In en, this message translates to:
  /// **'Financials'**
  String get financials;

  /// No description provided for @isAgentsReservation.
  ///
  /// In en, this message translates to:
  /// **'Agents reservation'**
  String get isAgentsReservation;

  /// No description provided for @isOrdered.
  ///
  /// In en, this message translates to:
  /// **'Ordered'**
  String get isOrdered;

  /// No description provided for @tax.
  ///
  /// In en, this message translates to:
  /// **'Tax'**
  String get tax;

  /// No description provided for @discount.
  ///
  /// In en, this message translates to:
  /// **'Discount'**
  String get discount;

  /// No description provided for @chat.
  ///
  /// In en, this message translates to:
  /// **'Chat'**
  String get chat;

  /// No description provided for @itinerary.
  ///
  /// In en, this message translates to:
  /// **'Itinerary'**
  String get itinerary;

  /// No description provided for @reservations.
  ///
  /// In en, this message translates to:
  /// **'Reservations'**
  String get reservations;

  /// No description provided for @requests.
  ///
  /// In en, this message translates to:
  /// **'Requests'**
  String get requests;

  /// No description provided for @pickupDrop.
  ///
  /// In en, this message translates to:
  /// **'pick & drop'**
  String get pickupDrop;

  /// No description provided for @status.
  ///
  /// In en, this message translates to:
  /// **'Status'**
  String get status;

  /// No description provided for @anEstimate.
  ///
  /// In en, this message translates to:
  /// **'Estimate'**
  String get anEstimate;

  /// No description provided for @waitingList.
  ///
  /// In en, this message translates to:
  /// **'Waiting list'**
  String get waitingList;

  /// No description provided for @paidBy.
  ///
  /// In en, this message translates to:
  /// **'Paid by'**
  String get paidBy;

  /// No description provided for @employee.
  ///
  /// In en, this message translates to:
  /// **'Employee'**
  String get employee;

  /// No description provided for @creditCard.
  ///
  /// In en, this message translates to:
  /// **'Credit card'**
  String get creditCard;

  /// No description provided for @pickupPlace.
  ///
  /// In en, this message translates to:
  /// **'Location'**
  String get pickupPlace;

  /// No description provided for @dropPlace.
  ///
  /// In en, this message translates to:
  /// **'Location'**
  String get dropPlace;

  /// No description provided for @budgetAccount.
  ///
  /// In en, this message translates to:
  /// **'Budget account'**
  String get budgetAccount;

  /// No description provided for @customer.
  ///
  /// In en, this message translates to:
  /// **'Customer'**
  String get customer;

  /// No description provided for @overlappingErr.
  ///
  /// In en, this message translates to:
  /// **'Overlapping %1\$ dates'**
  String get overlappingErr;

  /// No description provided for @summary.
  ///
  /// In en, this message translates to:
  /// **'Summary'**
  String get summary;

  /// No description provided for @startRangeErr.
  ///
  /// In en, this message translates to:
  /// **'Not earlier than %1\$'**
  String get startRangeErr;

  /// No description provided for @rangeErr.
  ///
  /// In en, this message translates to:
  /// **'Between %1\$ and %2\$'**
  String get rangeErr;

  /// No description provided for @hasReservation.
  ///
  /// In en, this message translates to:
  /// **'Has reservation'**
  String get hasReservation;

  /// No description provided for @selfPaid.
  ///
  /// In en, this message translates to:
  /// **'Self paid'**
  String get selfPaid;

  /// No description provided for @periodTotal.
  ///
  /// In en, this message translates to:
  /// **'Period Total'**
  String get periodTotal;

  /// No description provided for @perDay.
  ///
  /// In en, this message translates to:
  /// **'Per day'**
  String get perDay;

  /// No description provided for @details.
  ///
  /// In en, this message translates to:
  /// **'Details'**
  String get details;

  /// No description provided for @nights.
  ///
  /// In en, this message translates to:
  /// **'Nights'**
  String get nights;

  /// No description provided for @checkIn.
  ///
  /// In en, this message translates to:
  /// **'Check in'**
  String get checkIn;

  /// No description provided for @checkOut.
  ///
  /// In en, this message translates to:
  /// **'Check out'**
  String get checkOut;

  /// No description provided for @hotels.
  ///
  /// In en, this message translates to:
  /// **'Hotels'**
  String get hotels;

  /// No description provided for @next.
  ///
  /// In en, this message translates to:
  /// **'Next'**
  String get next;

  /// No description provided for @back.
  ///
  /// In en, this message translates to:
  /// **'Back'**
  String get back;

  /// No description provided for @done.
  ///
  /// In en, this message translates to:
  /// **'Done'**
  String get done;

  /// No description provided for @trains.
  ///
  /// In en, this message translates to:
  /// **'Trains'**
  String get trains;

  /// No description provided for @train.
  ///
  /// In en, this message translates to:
  /// **'Train'**
  String get train;

  /// No description provided for @dates.
  ///
  /// In en, this message translates to:
  /// **'Dates'**
  String get dates;

  /// No description provided for @hotel.
  ///
  /// In en, this message translates to:
  /// **'Hotel'**
  String get hotel;

  /// No description provided for @agency.
  ///
  /// In en, this message translates to:
  /// **'Agency'**
  String get agency;

  /// No description provided for @reservation.
  ///
  /// In en, this message translates to:
  /// **'Reservation'**
  String get reservation;

  /// No description provided for @map.
  ///
  /// In en, this message translates to:
  /// **'Map'**
  String get map;

  /// No description provided for @country.
  ///
  /// In en, this message translates to:
  /// **'Country'**
  String get country;

  /// No description provided for @pickUp.
  ///
  /// In en, this message translates to:
  /// **'Pick up'**
  String get pickUp;

  /// No description provided for @direction.
  ///
  /// In en, this message translates to:
  /// **'Direction'**
  String get direction;

  /// No description provided for @roundtrip.
  ///
  /// In en, this message translates to:
  /// **'Return'**
  String get roundtrip;

  /// No description provided for @oneWay.
  ///
  /// In en, this message translates to:
  /// **'OneWay'**
  String get oneWay;

  /// No description provided for @carClass.
  ///
  /// In en, this message translates to:
  /// **'Class'**
  String get carClass;

  /// No description provided for @carRentals.
  ///
  /// In en, this message translates to:
  /// **'Car Rentals'**
  String get carRentals;

  /// No description provided for @expenses.
  ///
  /// In en, this message translates to:
  /// **'Expenses'**
  String get expenses;

  /// No description provided for @vacations.
  ///
  /// In en, this message translates to:
  /// **'Vacations'**
  String get vacations;

  /// No description provided for @meetings.
  ///
  /// In en, this message translates to:
  /// **'Meetings'**
  String get meetings;

  /// No description provided for @profile.
  ///
  /// In en, this message translates to:
  /// **'Profile'**
  String get profile;

  /// No description provided for @place.
  ///
  /// In en, this message translates to:
  /// **'Place'**
  String get place;

  /// No description provided for @cash.
  ///
  /// In en, this message translates to:
  /// **'Cash'**
  String get cash;

  /// No description provided for @licenseNumber.
  ///
  /// In en, this message translates to:
  /// **'License number'**
  String get licenseNumber;

  /// No description provided for @agree.
  ///
  /// In en, this message translates to:
  /// **'I agree to company regulations'**
  String get agree;

  /// No description provided for @licenseExpires.
  ///
  /// In en, this message translates to:
  /// **'License Expires'**
  String get licenseExpires;

  /// No description provided for @mobilePhone.
  ///
  /// In en, this message translates to:
  /// **'Mobile phone'**
  String get mobilePhone;

  /// No description provided for @surname.
  ///
  /// In en, this message translates to:
  /// **'Surname'**
  String get surname;

  /// No description provided for @givenName.
  ///
  /// In en, this message translates to:
  /// **'Given name'**
  String get givenName;

  /// No description provided for @percentage.
  ///
  /// In en, this message translates to:
  /// **'Percentage'**
  String get percentage;

  /// No description provided for @origin.
  ///
  /// In en, this message translates to:
  /// **'Origin'**
  String get origin;

  /// No description provided for @airline.
  ///
  /// In en, this message translates to:
  /// **'Airline'**
  String get airline;

  /// No description provided for @arrival.
  ///
  /// In en, this message translates to:
  /// **'Arrival'**
  String get arrival;

  /// No description provided for @flightNumber.
  ///
  /// In en, this message translates to:
  /// **'Flight number'**
  String get flightNumber;

  /// No description provided for @recent.
  ///
  /// In en, this message translates to:
  /// **'Recent'**
  String get recent;

  /// No description provided for @departure.
  ///
  /// In en, this message translates to:
  /// **'Departure'**
  String get departure;

  /// No description provided for @destination.
  ///
  /// In en, this message translates to:
  /// **'Destination'**
  String get destination;

  /// No description provided for @days.
  ///
  /// In en, this message translates to:
  /// **'Days'**
  String get days;

  /// No description provided for @service.
  ///
  /// In en, this message translates to:
  /// **'Service'**
  String get service;

  /// No description provided for @purchase.
  ///
  /// In en, this message translates to:
  /// **'Purchase'**
  String get purchase;

  /// No description provided for @technicalBreakdown.
  ///
  /// In en, this message translates to:
  /// **'Technical breakdown'**
  String get technicalBreakdown;

  /// No description provided for @bdManufacturer.
  ///
  /// In en, this message translates to:
  /// **'BD manufacturer'**
  String get bdManufacturer;

  /// No description provided for @reason.
  ///
  /// In en, this message translates to:
  /// **'Reason'**
  String get reason;

  /// No description provided for @billable.
  ///
  /// In en, this message translates to:
  /// **'Billable'**
  String get billable;

  /// No description provided for @billableReason.
  ///
  /// In en, this message translates to:
  /// **'Billable reason'**
  String get billableReason;

  /// No description provided for @humanRelated.
  ///
  /// In en, this message translates to:
  /// **'Human related'**
  String get humanRelated;

  /// No description provided for @publicCloudServices.
  ///
  /// In en, this message translates to:
  /// **'Public cloud services'**
  String get publicCloudServices;

  /// No description provided for @description.
  ///
  /// In en, this message translates to:
  /// **'Description'**
  String get description;

  /// No description provided for @due.
  ///
  /// In en, this message translates to:
  /// **'Due date'**
  String get due;

  /// No description provided for @crmType.
  ///
  /// In en, this message translates to:
  /// **'CRM type'**
  String get crmType;

  /// No description provided for @organization.
  ///
  /// In en, this message translates to:
  /// **'Organization'**
  String get organization;

  /// No description provided for @purchaseType.
  ///
  /// In en, this message translates to:
  /// **'Type'**
  String get purchaseType;

  /// No description provided for @isCapital.
  ///
  /// In en, this message translates to:
  /// **'I wish to purchase a capital item'**
  String get isCapital;

  /// No description provided for @catalogNo.
  ///
  /// In en, this message translates to:
  /// **'Catalog no.'**
  String get catalogNo;

  /// No description provided for @unitPrice.
  ///
  /// In en, this message translates to:
  /// **'Unit price'**
  String get unitPrice;

  /// No description provided for @shipTo.
  ///
  /// In en, this message translates to:
  /// **'Ship to'**
  String get shipTo;

  /// No description provided for @dateOfPayment.
  ///
  /// In en, this message translates to:
  /// **'Date of payment'**
  String get dateOfPayment;

  /// No description provided for @dateMove.
  ///
  /// In en, this message translates to:
  /// **'Date move for payment'**
  String get dateMove;

  /// No description provided for @km.
  ///
  /// In en, this message translates to:
  /// **'km'**
  String get km;

  /// No description provided for @m.
  ///
  /// In en, this message translates to:
  /// **'m'**
  String get m;
}

class _AppLocalizationsDelegate extends LocalizationsDelegate<AppLocalizations> {
  const _AppLocalizationsDelegate();

  @override
  Future<AppLocalizations> load(Locale locale) {
    return SynchronousFuture<AppLocalizations>(lookupAppLocalizations(locale));
  }

  @override
  bool isSupported(Locale locale) => <String>['en', 'es'].contains(locale.languageCode);

  @override
  bool shouldReload(_AppLocalizationsDelegate old) => false;
}

AppLocalizations lookupAppLocalizations(Locale locale) {


  // Lookup logic when only language code is specified.
  switch (locale.languageCode) {
    case 'en': return AppLocalizationsEn();
    case 'es': return AppLocalizationsEs();
  }

  throw FlutterError(
    'AppLocalizations.delegate failed to load unsupported locale "$locale". This is likely '
    'an issue with the localizations generation tool. Please file an issue '
    'on GitHub with a reproducible sample app and the gen-l10n configuration '
    'that was used.'
  );
}
