import 'package:bizdoc/services/cube.dart';
import 'package:bizdoc/services/datasource.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:syncfusion_flutter_charts/charts.dart';

import 'package:bizdoc/services/session.dart';
import 'package:bizdoc/models/profile.dart';
import 'package:bizdoc/models/cube.dart';
import 'package:bizdoc/core/dashboard.dart';

/// Dashboard widget
class CubeAnalysisWidget extends StatefulWidget implements IDashboardWidget {
  const CubeAnalysisWidget({Key? key}) : super(key: key);

  @override
  _CubeAnalysisWidgetState createState() => _CubeAnalysisWidgetState();
}

class _CubeAnalysisWidgetState extends State<CubeAnalysisWidget> {
  late BizDocWidgetState _state;

  @override
  Widget build(BuildContext context) {
    return Consumer<BizDocWidgetState>(builder: (context, value, child) {
      _state = value;
      final chartType = CubeView.mapChartType(value.options['chartType']);
      if (value.hasData) {
        return FutureBuilder<Iterable<CubeSeries>>(
            future: _serialize(value.data),
            builder: (context, snapshot) {
              switch (chartType) {
                case ChartType.pie:
                  return SfCircularChart(
                    series: [
                      PieSeries(
                        dataSource: snapshot.data!.elementAt(0).points,
                        xValueMapper: (datum, index) => datum.xLabel,
                        yValueMapper: (datum, index) => datum.y,
                      )
                    ],
                  );
                case ChartType.doughnut:
                case ChartType.halfDoughnut:
                  return SfCircularChart(
                    series: [
                      DoughnutSeries(
                        startAngle: chartType == ChartType.doughnut ? 360 : 270,
                        endAngle: chartType == ChartType.doughnut ? 0 : 90,
                        dataSource: snapshot.data!.elementAt(0).points,
                        xValueMapper: (datum, index) => datum.xLabel,
                        yValueMapper: (datum, index) => datum.y,
                      )
                    ],
                  );
                default:
                  final series = <ChartSeries>[];
                  for (var dataSeries in snapshot.data!) {
                    switch (chartType) {
                      case ChartType.bar:
                        series.add(BarSeries<Point, String>(
                          dataSource: dataSeries.points,
                          xValueMapper: (datum, index) => datum.xLabel,
                          yValueMapper: (datum, index) => datum.y,
                        ));
                        break;
                      case ChartType.area:
                        series.add(AreaSeries<Point, String>(
                          dataSource: dataSeries.points,
                          xValueMapper: (datum, index) => datum.xLabel,
                          yValueMapper: (datum, index) => datum.y,
                        ));
                        break;
                      case ChartType.spline:
                        series.add(SplineSeries<Point, String>(
                          dataSource: dataSeries.points,
                          name: dataSeries.title,
                          xValueMapper: (datum, index) => datum.xLabel,
                          yValueMapper: (datum, index) => datum.y,
                        ));
                        break;
                      case ChartType.splineArea:
                        series.add(SplineAreaSeries<Point, String>(
                          dataSource: dataSeries.points,
                          name: dataSeries.title,
                          xValueMapper: (datum, index) => datum.xLabel,
                          yValueMapper: (datum, index) => datum.y,
                        ));
                        break;
                      case ChartType.stepLine:
                        series.add(StepLineSeries<Point, String>(
                          dataSource: dataSeries.points,
                          name: dataSeries.title,
                          xValueMapper: (datum, index) => datum.xLabel,
                          yValueMapper: (datum, index) => datum.y,
                        ));
                        break;
                      case ChartType.stackingBar:
                        series.add(StackedBarSeries<Point, String>(
                          dataSource: dataSeries.points,
                          name: dataSeries.title,
                          xValueMapper: (datum, index) => datum.xLabel,
                          yValueMapper: (datum, index) => datum.y,
                        ));
                        break;
                      case ChartType.stepArea:
                        series.add(StepAreaSeries<Point, String>(
                          dataSource: dataSeries.points,
                          name: dataSeries.title,
                          xValueMapper: (datum, index) => datum.xLabel,
                          yValueMapper: (datum, index) => datum.y,
                        ));
                        break;
                      case ChartType.stackingColumn:
                        series.add(StackedColumnSeries<Point, String>(
                          dataSource: dataSeries.points,
                          name: dataSeries.title,
                          xValueMapper: (datum, index) => datum.xLabel,
                          yValueMapper: (datum, index) => datum.y,
                        ));
                        break;
                      case ChartType.stackingLine:
                        series.add(StackedLineSeries<Point, String>(
                          dataSource: dataSeries.points,
                          name: dataSeries.title,
                          xValueMapper: (datum, index) => datum.xLabel,
                          yValueMapper: (datum, index) => datum.y,
                        ));
                        break;
                      case ChartType.stackingArea:
                        series.add(StackedAreaSeries<Point, String>(
                          dataSource: dataSeries.points,
                          name: dataSeries.title,
                          xValueMapper: (datum, index) => datum.xLabel,
                          yValueMapper: (datum, index) => datum.y,
                        ));
                        break;
                      default:
                        series.add(LineSeries<Point, String>(
                          dataSource: dataSeries.points,
                          xValueMapper: (datum, index) => datum.xLabel,
                          yValueMapper: (datum, index) => datum.y,
                        ));
                    }
                  }
                  return SfCartesianChart(
                    primaryXAxis: CategoryAxis(),
                    series: series,
                  );
              }
            });
      }
      return const Center(child: CircularProgressIndicator());
    });
  }

  Future<Iterable<CubeSeries>> _serialize(data) async {
    final cube = _state.options.containsKey('cube')
        ? session.profile.cubes
            .firstWhere((element) => element.name == _state.options['cube'])
        : session.profile.cubes.first;
    final xAxis = _state.options.containsKey('xAxis')
        ? List<String>.from(_state.options['xAxis'])
        : [cube.axes.first.name];
    final series = _state.options.containsKey('series')
        ? List<String>.from(_state.options['series'])
        : null;
    final columns = xAxis.toSet();
    if (series != null) columns.addAll(series);

    final Map<String, Map<String, dynamic>> map = {};
    final axes = cube.axes.where((element) => columns.contains(element.name));
    await Future.wait(axes.map((axis) {
      final name = axis.name;
      return dataSource.map(axis.dataType).then((ds) {
        return map[name] = ds;
      });
    }));

    final results =
        List<CubeSeries>.from(data.map((e) => CubeSeries.fromJson(e)));
    final base = results.elementAt(0);
    String translate(String key, List<String> axes) {
      final keys = key.split(complexAxisDivider), labels = [];
      for (var i = 0; i < keys.length; i++) {
        final val = data[axes[i]]![keys[i]];
        labels.add(val ?? keys[i]);
      }
      return labels.join('-');
    }

    var i = 0;
    for (var item in results) {
      for (var point in item.points) {
        point.xLabel = translate(point.x, xAxis);
        if (i > 0 && !base.points.any((element) => element.x == point.x)) {
          base.points.add(Point(point.x, 0));
        }
      }
      if (item.name != null) {
        item.title = translate(item.name!, series!);
      } else {
        final index =
            cube.indices.firstWhere((element) => element.name == item.index);
        item.title = index.title;
      }
      i++;
    }
    return results;
  }
}
