import 'package:bizdoc/services/accounts.dart';
import 'package:bizdoc/services/session.dart';
import 'package:flutter/material.dart';
import 'package:timeago/timeago.dart' as time_ago;

import 'package:bizdoc/models/profile.dart';

/// Lists contacts from [Profile] and enable searching server for users. Trigger [onTap]
class ContactsWidget extends StatefulWidget {
  final ValueChanged<ContactInfo> onTap;

  const ContactsWidget({Key? key, required this.onTap}) : super(key: key);
  @override
  _ContactsWidgetState createState() => _ContactsWidgetState();
}

class _ContactsWidgetState extends State<ContactsWidget> {
  late Future<Iterable<UserInfo>> _users;
  final _controller = TextEditingController();
  bool _searching = false;
  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        TextField(
          controller: _controller,
          onChanged: (value) {
            _users = findAll(_controller.text);
            setState(() => _searching = true);
          },
        ),
        if (_searching)
          FutureBuilder<Iterable<UserInfo>>(
              future: _users,
              builder: (context, snapshot) {
                if (snapshot.hasData) {
                  return ListView.builder(
                    itemCount: snapshot.data!.length,
                    itemBuilder: (context, index) {
                      var item = snapshot.data!.elementAt(index);
                      return ListTile(
                        title: Text(item.name),
                        onTap: () {
                          final find = session.profile.contacts.firstWhere(
                              (element) => element.id == item.id, orElse: () {
                            final element = ContactInfo.from(item);
                            session.profile.contacts.insert(0, element);
                            return element;
                          });
                          widget.onTap(find);
                        },
                      );
                    },
                  );
                }
                return const LinearProgressIndicator();
              })
        else
          FutureBuilder(
              future: _decorate(),
              builder: (context, snapshot) {
                if (snapshot.hasData) {
                  return ListView.builder(
                    itemCount: session.profile.contacts.length,
                    itemBuilder: (context, index) {
                      final item = session.profile.contacts.elementAt(index);
                      return ListTile(
                        title: Text(item.id),
                        subtitle: Text(time_ago.format(item.time)),
                        onTap: () => widget.onTap(item),
                      );
                    },
                  );
                }
                return const LinearProgressIndicator();
              }),
      ],
    );
  }

  Future _decorate() => Future.wait(session.profile.contacts.map(
      (item) => users.find(item.id).then((info) => item.name = info.name)));

  Future<Iterable<UserInfo>> findAll(String name) async {
    try {
      return await users.findAll(name);
    } catch (e) {}
    return List.empty();
  }
}
