import 'package:flutter/material.dart';

import '../core/icon.dart';
import '../models/profile.dart';

import '../services.dart';

/// Home main drawer. Trigger [onTap] of one of [EventBase]
class MainDrawer extends StatefulWidget {
  final Function(EventBase) onTap;
  const MainDrawer({Key? key, required this.onTap}) : super(key: key);
  @override
  _MainDrawerState createState() => _MainDrawerState();
}

class _MainDrawerState extends State<MainDrawer> {
  late Profile _profile;
  @override
  void initState() {
    _profile = session.profile;
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    var children = [
      // DrawerHeader(
      //     child: Column(
      //   children: [Text('')],
      // )),
      ListTile(
        //title: Text(AppLocalizations.of(context)!.dashboard),
        leading: const Icon(Icons.apps_outlined),
        onTap: () => onTap(DashboardEvent()),
      ),
      ListTile(
        //title: Text(AppLocalizations.of(context)!.favorites),
        leading: const Icon(Icons.flag_outlined),
        onTap: () => onTap(FolderEvent(queryType: QueryType.flagged)),
      ),
      const Divider(),
    ];
    children.addAll(_profile.folders.map((item) => ListTile(
          title: Text(item.title),
          leading: Icon(iconData(item.icon)),
          onTap: () => onTap(FolderEvent(folderId: item.name)),
        )));
    children.add(const Divider());
    for (var cube in _profile.cubes) {
      children.addAll(cube.views.map((view) => ListTile(
            title: Text(view.title),
            onTap: () => onTap(CubeEvent(cube, view)),
          )));
    }
    return Column(
      children: children,
    );
  }

  onTap(EventBase event) {
    Navigator.pop(context);
    widget.onTap(event);
  }
}

abstract class EventBase {}

class FolderEvent extends EventBase {
  final String? folderId;
  final QueryType? queryType;
  FolderEvent({this.folderId, this.queryType});
}

class CubeEvent extends EventBase {
  final CubeInfo cube;
  final CubeView view;
  CubeEvent(this.cube, this.view);
}

class DashboardEvent extends EventBase {}
