import 'package:bizdoc/models/cube.dart';
import 'package:bizdoc/services/cube.dart';
import 'package:flutter/material.dart';

class ExplorePage extends StatefulWidget {
  static String routeName = 'explore';

  const ExplorePage({Key? key}) : super(key: key);
  @override
  _ExplorePageState createState() => _ExplorePageState();
}

class _ExplorePageState extends State<ExplorePage> {
  late Future<List> _prepare;
  @override
  void initState() {
    final model = ModalRoute.of(context)!.settings.arguments as ExploreArgs;
    _prepare = Future.wait([
      cube.resolve(model.cube, axes: model.axes),
      cube.explore(model.cube, axes: model.axes)
    ]);
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return FutureBuilder<List>(
      future: _prepare,
      builder: (context, snapshot) {
        if (snapshot.hasData) {
          final type = snapshot.data!.elementAt(0) as ExploreType;
          final items =
              snapshot.data!.elementAt(1) as List<Map<String, dynamic>>;
          return ListView.builder(
            itemCount: items.length,
            itemBuilder: (context, index) {
              final item = items.elementAt(index);
              return ListTile(
                title: Text(item[type.columns.first.name]),
                subtitle: Text(item[type.columns.elementAt(1).name]),
              );
            },
          );
        }
        return const CircularProgressIndicator();
      },
    );
  }
}

class ExploreArgs {
  final String cube;
  Map<String, dynamic> axes;
  String? index;
  ExploreArgs(this.cube, {required this.axes, this.index});
}
